#!/usr/bin/env python3

import sys
import os

sys.path.insert(0, os.path.dirname(os.path.realpath(__file__)) + "/../build")

from pywpsrpc.rpcetapi import etapi
from pywpsrpc import (rpcetapi, common)
from pywpsrpc.utils import RpcIter


def check_call(funcName, hr, value=None):
    if common.FAILED(hr):
        print("call {} failed with code: {}".format(funcName, hr))
        sys.exit(-1)
    if value != None:
        print("{}: {}".format(funcName, value))
    else:
        print("{}: <ok>".format(funcName))


def test():
    hr, rpc = rpcetapi.createEtRpcInstance()
    check_call("rpcetapi.createEtRpcInstance", hr, rpc)

    hr, app = rpc.getEtApplication()
    check_call("rpc.getEtApplication", hr, app)

    hr, pid = rpc.getProcessPid()
    check_call("rpc.getProcessPid", hr, pid)

    hr, workbooks = app.get_Workbooks()
    check_call("app.get_Workbooks", hr ,workbooks)

    hr, workbook = workbooks.Add()
    check_call("workbooks.Add", hr, workbook)

    hr, sheet = workbook.get_ActiveSheet()
    check_call("workbook.get_ActiveSheet", hr, sheet)

    hr, rg = sheet.get_Range("A1")
    check_call("sheet.get_Range", hr, rg)

    hr = rg.put_Value(RHS="test")
    check_call("rg.put_Value", hr)

    hr, window = app.get_ActiveWindow()
    check_call("app.get_ActiveWindow", hr, window)

    hr, winType = window.get_Type()
    check_call("window.get_Type", hr, winType)

    props = workbook.CustomDocumentProperties
    print("Doc Props:")
    for prop in RpcIter(props):
        print("\t %s: %s" % (prop.Name, prop.Value))

    props = workbook.BuiltinDocumentProperties
    print("Builtin Props:")
    for prop in RpcIter(props):
        print("\t %s: %s" % (prop.Name, prop.Value))

    hr = workbook.Close()
    check_call("workbook.Close", hr)


    app.Quit()


if __name__ == "__main__":
    test()



#!/usr/bin/env python3

import sys
import os

sys.path.insert(0, os.path.dirname(os.path.realpath(__file__)) + "/../build")
from pywpsrpc import RpcProxy, RpcIter
from pywpsrpc.rpcwpsapi import createWpsRpcInstance
from pywpsrpc.rpcwppapi import createWppRpcInstance
from pywpsrpc.rpcetapi import createEtRpcInstance


def test_wps():
    hr, rpc = createWpsRpcInstance()
    app = RpcProxy(rpc.getWpsApplication())
    docs = app.Documents

    docs.Add()
    print(len(docs))

    docs.Add()
    print(len(docs))

    # index starts from 1, not 0
    for i in range(1, len(docs) + 1):
        print("index.docName: ", docs[i].Name)

    for doc in docs:
        print("iter.docName: ", doc.Name)

    # use raw object
    for doc in RpcIter(docs.rpc_object):
        print("iter2.docName: ", doc.Name)

    # access by name
    name = docs[2].Name
    doc = docs[name]
    print("doc", doc.Name)

    doc = docs.Open(os.path.dirname(os.path.realpath(__file__)) + "/../pyproject.toml", ReadOnly=True)
    for para in doc.Paragraphs:
        print(para.Range.Text)

    app.Quit()


def test_wpp():
    hr, rpc = createWppRpcInstance()
    app = RpcProxy(rpc.getWppApplication())

    preses = app.Presentations
    print(len(preses))

    preses.Add()
    print(len(preses))

    preses.Add()
    print(len(preses))

    for pres in preses:
        print(pres.Name)

    app.Quit()


def test_et():
    hr, rpc = createEtRpcInstance()
    app = RpcProxy(rpc.getEtApplication())

    wbs = app.Workbooks
    print(len(wbs))

    wbs.Add()
    print(len(wbs))

    wbs.Add()
    print(len(wbs))

    for wb in wbs:
        print(wb.Name)
        for sheet in wb.Sheets:
            print(sheet.Name)

    app.Quit()


def main():
    test_wps()
    test_wpp()
    test_et()


if __name__ == "__main__":
    main()



#!/usr/bin/env python3

import sys
import os
import datetime

sys.path.insert(0, os.path.dirname(os.path.realpath(__file__)) + "/../build")

from pywpsrpc.rpcwppapi import wppapi
from pywpsrpc import (rpcwppapi, common)
from pywpsrpc.utils import RpcIter


def check_call(funcName, hr, value=None):
    if not common.SUCCEEDED(hr):
        print("call {} failed with code: {}".format(funcName, hr))
        sys.exit(-1)
    if value != None:
        print("{}: {}".format(funcName, value))
    else:
        print("{}: <ok>".format(funcName))


def test():
    hr, rpc = rpcwppapi.createWppRpcInstance()
    check_call("rpcwppapi.createWppRpcInstance", hr, rpc)

    hr, app = rpc.getWppApplication()
    check_call("rpc.getWppApplication", hr, app)

    hr, pid = rpc.getProcessPid()
    check_call("rpc.getProcessPid", hr, pid)

    hr, preses = app.get_Presentations()
    check_call("app.get_Presentations", hr, preses)

    hr, pres = preses.Add(wppapi.msoTrue)
    check_call("preses.Add", hr, pres)

    hr, pres = app.get_ActivePresentation()
    check_call("app.get_ActivePresentation", hr, pres)

    hr, name = pres.get_FullName()
    check_call("pres.get_FullName", hr, name)

    props = pres.CustomDocumentProperties
    print("Doc Props:")
    for prop in RpcIter(props):
        print("\t %s: %s" % (prop.Name, prop.Value))

    a_date = datetime.date(2020, 7, 20)
    hr, prop = props.Add("_a_date", False, Value=a_date)
    assert(hr == common.S_OK and prop.Value.date() == a_date)

    a_datetime = datetime.datetime(2020, 7, 21, 14, 15, 30)
    hr, prop = props.Add("_a_datetime", False, Value=a_datetime)
    assert(hr == common.S_OK and prop.Value == a_datetime)

    props = pres.BuiltInDocumentProperties
    print("Builtin Props:")
    for prop in RpcIter(props):
        print("\t %s: %s" % (prop.Name, prop.Value))

    hr = pres.Close()
    check_call("pres.Close", hr)

    hr = app.Quit()
    check_call("ap.Quit", hr)


if __name__ == "__main__":
    test()



#!/usr/bin/env python3

import sys
import os

sys.path.insert(0, os.path.dirname(os.path.realpath(__file__)) + "/../build")


def test_wps():
    try:
        from pywpsrpc.rpcwpsapi import createWpsRpcInstance
    except ImportError:
        return

    hr, rpc = createWpsRpcInstance()
    hr, app = rpc.getWpsApplication()

    visible = app.Visible
    print(visible)
    app.Visible = False
    print(app.Visible)
    app.Visible = True

    assert(app.Documents.Count == 0)

    try:
        doc = app.ActiveDocument
        assert(False)
    except AttributeError as e:
        print(e)

    try:
        app.ActiveDocument = None
        assert(False)
    except AttributeError as e:
        print(e)

    hr, doc = app.Documents.Add()
    assert(app.Documents.Count == 1)

    print(doc.Name)
    doc.Close()

    app.Quit()


def test_et():
    try:
        from pywpsrpc.rpcetapi import createEtRpcInstance, etapi
    except ImportError:
        return

    hr, rpc = createEtRpcInstance()
    hr, app = rpc.getEtApplication()

    workbooks = app.Workbooks
    assert(workbooks.Count == 0)

    hr, workbook = workbooks.Add()
    assert(workbooks.Count == 1)

    sheet = workbook.ActiveSheet
    print(sheet.Name)

    hr, rg = sheet.get_Range("A1")
    rg.Value = "test"

    assert(sheet.get_Range("A1")[1].Value == "test")

    workbook.Close(SaveChanges=False)

    app.Quit()


if __name__ == "__main__":
    test_wps()
    test_et()
